CluSeek is a graphical bioinformatics application for finding co-localized protein coding sequences in genomic data in the NCBI GenBank database, such as gene clusters.

Tested on Windows 7-11 and Linux. Requires the [USEARCH software](https://drive5.com/usearch/download.html) to be present in the workding directory and named as such in order to function properly.

Please visit [our website](www.cluseek.com) for more complete details on its purpose, installation and usage.
